Coverage for C:\src\imod-python\imod\mf6\utilities\regridding_types.py: 100%

1 from enum import Enum

2

3 import xugrid as xu

4

5

6 class RegridderType(Enum):

7 """

8 Enumerator referring to regridder types in ``xugrid``.

9 These can be used safely in scripts, remaining backwards compatible for

10 when it is decided to rename regridders in ``xugrid``. For an explanation

11 what each regridder type does, we refer to the `xugrid documentation <https://deltares.github.io/xugrid/examples/regridder_overview.html>`_

12 """

13

14 CENTROIDLOCATOR = xu.CentroidLocatorRegridder

15 BARYCENTRIC = xu.BarycentricInterpolator

16 OVERLAP = xu.OverlapRegridder

17 RELATIVEOVERLAP = xu.RelativeOverlapRegridder